/* globals CatturaBox */
/* globals ko */

var _ = require("lodash");
var notify = require("./components/notify");
var plugin = require("./plugins").observablePlugin("KalturaSchedulerPlugin");

// Kaltura plugin ID. We need this to filter valid templates.
var KALTURA_PLUGIN_ID = "com.cattura.kaltura_plugin.KalturaPlugin";

// Valid templates for Kaltura config.
var validTemplates = ko.computed(function () {
    return _(CatturaBox.templates.templates()).filter(function (template) {
        return _(template.uniquePublishers()).find(function (publisher) {
            return publisher.platform === KALTURA_PLUGIN_ID;
        });
    }).value();
});

// Connection status
var status = ko.observable({
    success: false,
    enabled: false,
    message: "Unknown",
    timestamp: -1,
    registered: false,
    resourceName: null
});

function refreshEventSource ()
{
    return plugin().services["refresh"]({}).then(function (returnStatus) {
        status(returnStatus);
        if (returnStatus.success)
        {
            notify.success("Kaltura Scheduler was refreshed successfully: " + returnStatus.message);
        }
        else
        {
            notify.error("Kaltura Scheduler was not refreshed successfully: " + returnStatus.message);
        }
    });
}

function refreshStatus ()
{
    return plugin().services["getStatus"]({}).then(function (returnStatus) {
        status(returnStatus);
        return returnStatus;
    });
}

var config = ko.adapterObservable(function (value) {
    return ko.mapping.fromJS(_({
        template: null,
        'poll-period-sec': null
    }).extend(value).value());
});

var isConfigValid = ko.computed(function () {
    return validTemplates().length > 0;
});

config({});

// Register as an external scheduler
CatturaBox.externalScheduling.add("kaltura", {
    label: "Kaltura",
    
    status: status,
    refresh: refreshEventSource,
    
    validTemplates: validTemplates,
    
    config: config,
    isConfigValid: isConfigValid
});

// Events from the recorder
addEventListener("KalturaSchedulerStatusEvent", function (event) {
    status(event.status);
});

// UI hooks
var settingsPanelTemplate = this.templates.settingsPanel;
addEventListener("buildExternalSchedulingTab", function (event) {
    if (event.provider.id !== "kaltura")
    {
        return;
    }
    
    event.element.append(settingsPanelTemplate());
});

addEventListener("INIT", function () {
    refreshStatus();
});